@@ -3,14 +3,12 @@ def warn(msg, from=nil)
 end
 
 def to_location(from)
-  op = nil
   token = case from
     when Token
       from
     when AST
       from.token
     when IR
-      op = from.op.name
       from.token
     when NilClass
       nil
@@ -19,7 +17,7 @@ def to_location(from)
     end
 
   if token
-    "%s:%s (%s) " % [token.line_no||"?", token.char_no||"?", op && op.downcase != token.str.downcase ? "#{token.str} #{op}" : token.str]
+    "%s:%s (%s) " % [token.line_no||"?", token.char_no||"?", token.str]
   else
     ""
   end
