@@ -43,11 +43,11 @@ def parse_str_char(s,i) # parse char in a string starting at position i
 end
 
 def parse_str(s)
-  i=0
+  i=1 # skip initial "
   r=""
-  while i<s.size
+  while i<s.size && s[i] != '"'
     c,i=parse_str_char(s,i)
     r<<c
   end
-  r
-end
+  [r, s[i..-1]]
+end
\ No newline at end of file
