@@ -290,16 +290,6 @@ if Encoding.default_external != ByteEncoding
   Header.gsub!('hSetEncoding stdout char8','')
 end
 
-def to_hs_type(type, rank)
-  (type == EmptyType ? "Ord a => " : "") +
-    type_and_rank_to_str(type == EmptyType ? "a" : "Integer", rank)
-end
-
-ZipNames = ["", "map", "zipWith", "zipWith3"]
-def to_hs_zips(n, nargs, op)
-  n <= 0 ? op : "#{ZipNames[nargs]} (#{to_hs_zips(n-1, nargs, op)})"
-end
-
 def does_source_use_input(source)
   $input_checked = false
   begin
@@ -309,6 +299,11 @@ def does_source_use_input(source)
   $input_checked
 end
 
+ZipNames = ["", "map", "zipWith", "zipWith3"]
+def to_hs_zips(n, nargs, op)
+  n <= 0 ? op : "#{ZipNames[nargs]} (#{to_hs_zips(n-1, nargs, op)})"
+end
+
 def generate_hs(source, pp_sep)
   output Header
 
@@ -324,7 +319,7 @@ def generate_hs(source, pp_sep)
    iogRawStdinLines = iogLines $ map myOrd hsStdin\n"
    possible_input_formats = ["a\nb",["a\nb","a\nb"]]
   else
-    if !does_source_use_input(source) # do this to avoid unnecessarily awaiting input that is never used
+    if !does_source_use_input(source) # do this to avoid unnecessarily awaiting input that is never used (awaiting in the haskell program)
       output "iogMain hsArgs hsStdin = iogMainListEmpty [] where\n"
       possible_input_formats = [""]
     else
@@ -421,7 +416,6 @@ def to_hs_main(ir3, ir3_ind)
       end
     end
 
-    output "    a#{i} :: #{to_hs_type(node.type, node.rank)}\n"
     output "    a#{i} = #{to_hs_zips(node.zip_level, node.args.size, op)} #{args}\n"
   }
   output "  in map myChr a#{ir3_ind}\n"
