@@ -12,16 +12,29 @@ if ["-v", "--version"].any?{|option| ARGV.delete(option) }
   exit
 end
 
-pretty_print = ["-pp", "--pretty_print"].any?{|option| ARGV.delete(option) }
+pretty_print = ["-p", "--pretty_print"].any?{|option| ARGV.delete(option) }
 hs = ["-hs", "--hs"].any?{|option| ARGV.delete(option) }
 
+def usage
+  raise IogiiError.new "usage: ruby #$0 -v,--version | [-p,--pretty_print] [-hs,--hs] <filename.iog> [-- rawargs*]"
+end
+
 begin
-  raise IogiiError.new "usage: ruby #$0 -v,--version | [-p,--pretty_print] [-hs,--hs] <filename.iog> [-- rawargs*]" if ARGV.size == 0 || ARGV.any?{|a| a[0] == "-" }
+  usage if ARGV.size == 0
+
+  unknown_options = ARGV.select{|a| a[0] == "-" }
+  if !unknown_options.empty?
+    STDERR.puts "unknown options: " + unknown_options*" "
+    usage
+  end
+
   raise IogiiError.new "mustn't give more than one file arg" if ARGV.size > 1
+
   if ARGV.size == 1
     raise IogiiError.new "file does not exist: %p" % ARGV[0] if !File.file?(ARGV[0])
     program = IO.binread(ARGV[0])
   end
+
   run_and_do_io(program, input, pretty_print, hs)
 rescue IogiiError => e
   STDERR.puts e.message
