@@ -148,12 +148,12 @@ mk_op("(, min", "a a -> a", '4 5 (, -> 4'){|a,b| spaceship(a,b) <= 0 ? a.value :
 mk_op("x max", "a a -> a", '"bc" "ad" x -> "bd"'){|a,b| spaceship(a,b) >= 0 ? a.value : b.value }
 mk_op("y yesNo ifElse", "b a a -> a", '0 1 2 y -> 2', promote: NotFirst){|a,b,c| truthy($at, a.value) ? b.value : c.value }
 mk_op("z zeroPad padDefault", "[a] -> [a]", '1,2,3 z -> [1,2,3,0,0,...', uses_zero: true){|a| padv(a, zero($rank,$at).const) }
-mk_op("\\ exclude setDiff", "[a] [a] -> [a]", '"abra" "ra"\\ -> "ba"'){|a,b| set_diff(a,b) }
+mk_op("\\ setDiff", "[a] [a] -> [a]", '"abra" "ra"\\ -> "ba"'){|a,b| set_diff(a,b) }
 mk_op("< lessThan", "a a -> int", '1,2,3 2< -> [1,0,0]'){|a,b| spaceship(a,b) == -1 ? 1 : 0 }
 mk_op("& sortBy", "[a] [b] -> [a]", '"abc","d":len &, -> ["d","abc"]', promote: false){|a,b| sort_by(a,b) }
 mk_op("| chunkWhen", "[a] [b] -> [[a]]", '"ab cd e":| -> ["ab ","cd ","e"]', promote: false){|a,b| chunk_while(a,b,$bt) } # promote false is for rank invariant (could actually be useful otherwise)
 mk_op("@ indices", "[a] a -> [int]", '"abcdc" \'c @ -> [2,4]'){|a,b| indices(a,b) }
-mk_op("? debut isFirst", "[a] -> [int]", '"aardvark"? -> [1,0,1,1,1,0,0,1]', promote: false){|a| isuniq(a) }
+mk_op("? isFirst", "[a] -> [int]", '"aardvark"? -> [1,0,1,1,1,0,0,1]', promote: false){|a| isuniq(a) }
 mk_op("[ init", "[a] -> [a]", '"abc" [ -> "ab"', promote: false){|a| init(a) }
 
 category('<a href="ops.html#slicingops">slicing ops</a> (char instead of int is substring, uppercase = any)')
@@ -171,15 +171,15 @@ mk_op("f foldr", "a -> [a]", '0 f 1,2,3+ -> 6', block: true)
 mk_op("m meld foldr0", "[a]", 'm 1,2,3+ -> 6', block: true)
 
 category('<a href="syntax.html#otherwaystousevaluesmultipletimes">stack ops</a> (fns do match >)')
-mk_op(": dup", "a -> a", "5: -> 5 5")
-mk_op("; mdup", "a -> a", "5;1- -> 4 5", block: true)
-mk_op("] peek", "a b -> b", "5 4 ] -> 5 4 5")
-mk_op("! mpeek", "a b -> b", "5 4 ! 1+ -> 6 4 5", block: true)
+mk_op(": dup", "a -> a", "5: -> 5 5", vectorize: false)
+mk_op("; mdup", "a -> a", "5;1- -> 4 5", block: true, vectorize: false)
+mk_op("] peek", "a b -> b", "5 4 ] -> 5 4 5", vectorize: false)
+mk_op("! mpeek", "a b -> b", "5 4 ! 1+ -> 6 4 5", block: true, vectorize: false)
 
 category("special symbols")
 quickref_op("$", "arg", "5;$+ -> 10 5")
 quickref_op(">", '<a href="syntax.html#codeclassinlinegtcodematching">end loop</a> or set <a href="syntax.html#implicitvalues">implicit</a>', "e))> -> [2,4,6...")
-quickref_op(",", '<a href="vectorization.html">unvec</a> or data format or <a href="IO.html#autoparsing">raw mode</a>', '"ab"j, -> ["ab"]')
+quickref_op(",", '<a href="vectorization.html">unvec</a> or data format or <a href="IO.html#rawmodes">raw mode</a>', '"ab"j, -> ["ab"]')
 quickref_op("=", "set next var", "5= A -> 5 5")
 
 category('<a href="types.html#lowrankoverrides">low rank overloads</a><br> (number of *\'s = number of times you may vectorize arg before needing ",")')
@@ -187,15 +187,17 @@ mk_op("U uppercase", "char** -> char", "'a U -> 'A'"){|a| a=a.value; a>='a'.ord
 mk_op("L lowercase", "char* -> char", "'A L -> 'a'"){|a| a=a.value; a>='A'.ord && a<='Z'.ord ? a+32 : a }
 mk_op("p lines", "[char] -> [[char]]", '"ab\nc\n" p -> ["ab","c"]'){|a| lines(a) }
 mk_op("P charClass", "[char]* -> [char]", '"x" P -> "abc...z"'){|a| concat(char_class(a).const) }
-mk_op("P digits", "int** -> [int]", '123 P -> [1,2,3]'){|a| v=to_base(a.value,10); v.empty? ? [0.const, Null] : v }
+mk_op("P digits", "int** -> [int]", '123 P -> [1,2,3]'){|a| v=to_base(a.value,10); v.empty? ? [0.const, Null] : reverse(v.const) }
 mk_op("U undigits", "[int]* -> int", '1,2,3 U -> 123', promote: false){|a| undigits(a) }
 mk_op("L lenFrom0 abs", "int* -> int", '5~L -> 5'){|a| a.value.abs }
-mk_op("D doBase toBase", "int* int -> [int]", '6 2 D -> [1,1,0]'){|a,b| to_base(a.value,b.value) }
-mk_op("# baseFrom", "int [x] -> int", '2 1,1,0 # -> 6', promote: false){|a,b| from_base(b.value,a.value) }
+mk_op("D digitsBase toBase", "int* int -> [int]", '6 2 D -> [1,1,0]'){|a,b| reverse(to_base(a.value,b.value).const) }
+mk_op("X exBase fromBase", "[int] int -> int", '1,1,0 2 X -> 6', promote: false){|a,b| from_base(a.value,b.value) }
+mk_op("p bits", "int* -> [int]", "6 p -> [0,1,1]"){|a| to_base(a.value, 2) }
 mk_op("B rangeFrom rangeBegin", "x* -> [x]", "2B -> [2,3,4,..."){|a| range_from(a.value) }
 mk_op("T rangeTo", "x* -> [x]", "3T -> [0,1,2]"){|a| range(zero(0,$at),a.value) }
 mk_op("u unsquare sqrt", "int* -> int", "9u -> 3"){|a| square_root(a.value, 2) }
-mk_op("H hyper pow10", "int* -> int", "2H -> 100"){|a| pow(10, a.value) }
+mk_op("H powOf10", "int* -> int", "2H -> 100"){|a| pow(10, a.value) }
+mk_op("h powOf2", "int -> int", "8h -> 256"){|a| pow(2, a.value) }
 
 category("debugging ops")
 mk_op("nil", "[a]", 'nil -> []'){ [] }
@@ -206,11 +208,11 @@ mk_op("version", "[char]", "version -> \"#{Version}, ruby#{RUBY_VERSION}\""){ st
 mk_op("del", "a -> ", '1 2 del -> 1', vectorize: false){|a| raise}
 mk_op("let", "a -> ", "5 let a  a a+ -> 10", vectorize: false)
 mk_op("set", "a -> a", "5 set a( a) -> 4 6", vectorize: false)
-mk_op("input", "a")
-mk_op("implicit", "a")
+mk_op("input", "a", vectorize: false)
+mk_op("implicit", "a", vectorize: false)
 
 category("internal ops")
-mk_op("$", "a")
+mk_op("$", "a", vectorize: false)
 mk_op("superpad", "[a] -> [a]", promote: false){ raise }
 mk_op("estr", "empty -> [char]"){|a| a.value } # empty type to str (for haskell type coercion)
 
