@@ -170,7 +170,7 @@ def route_to_ancestor(parent, child, nodes)
   nil
 end
 
-def build_tree(tokens, registers, null_input, last_unmatched = nil)
+def build_tree(tokens, registers, input_present, last_unmatched = nil)
   # it is important for each token to only be responsible for adding 1 value to the stack, that way rotating the main program can choose a break point at any point. That why adding multiple is accomplished by creating virtual tokens that are responsible for the other values.
 
   stack = []
@@ -259,15 +259,13 @@ def build_tree(tokens, registers, null_input, last_unmatched = nil)
         push[AST.new(t, args, :IdentityNode)]
         insert_duped[nodes.size-1,[0,1]]
       elsif op.name == "$"
-        if all_lbs.empty?
-          if null_input.value
-            push[AST.new(t, [], :ImplicitValue)]
-          else
-            nodes << mk_input_node
-            push[AST.new(t, [], :ArgNode, nodes.size - 1)]
-          end
-        else
+        if !all_lbs.empty?
           push[AST.new(t, [], :ArgNode, all_lbs[-1])]
+        elsif input_present.value
+          nodes << mk_input_node
+          push[AST.new(t, [], :ArgNode, nodes.size - 1)]
+        else
+          push[AST.new(t, [], :ImplicitValue)]
         end
       elsif op.name == "input"
         push[mk_input_node(t)]
@@ -360,8 +358,7 @@ def parse_main(tokens, input_present)
   registers = get_var_ids_set(tokens)
   tokens = split_ids(tokens, registers)
   tokens = tokenize_data(tokens, registers)
-  null_input = promise{ $input_checked = true; !input_present }
-  nodes, stack, deleted, nimplicits, lbs = build_tree(tokens, registers, null_input)
+  nodes, stack, deleted, nimplicits, lbs = build_tree(tokens, registers, input_present)
   if nimplicits > 0
     unfinished_extra = lbs.map{|lb|
       case nodes[lb].token.str
@@ -382,12 +379,12 @@ def parse_main(tokens, input_present)
       last_token_ind += last_token.str == "let" || last_token.str == "set" ? 2 : 1
     end
 
-    input = Token.new(null_input.value ? "implicit" : "input", :id)
+    input = Token.new(input_present.value ? "input" : "implicit", :id)
 
     tokens = tokens[last_token_ind..-1] + [input] + tokens[0,last_token_ind]
 
     # build the tree after literally rotating the tokens, rather than manipulate the tree because the program rotation could have interupted functions which would not have been able to implicitly close
-    nodes, stack, deleted, nimplicits, lbs = build_tree(tokens, registers, null_input)
+    nodes, stack, deleted, nimplicits, lbs = build_tree(tokens, registers, input_present)
   end
 
 #     puts tokens.map(&:str)*" "
@@ -396,7 +393,7 @@ def parse_main(tokens, input_present)
 
   last_unmatched = nodes.reverse_each.find{|n| n.type == :UnmatchedEndBracket }
 
-  nodes, stack, deleted, nimplicits, lbs = build_tree(tokens, registers, null_input, last_unmatched)
+  nodes, stack, deleted, nimplicits, lbs = build_tree(tokens, registers, input_present, last_unmatched)
   raise IogiiError.new("unterminated function", nodes[lbs[-1]]) if !lbs.empty?
 
   if last_unmatched
