@@ -21,14 +21,14 @@ def gen_graph(source, input, pp_sep: nil, ast_cb: nil, ir_cb: nil)
 
   input_mode = input_mode(source)
   if input_mode == :auto_parse_mode
-    inputs = read_inputs(input)
-    input_present = !!inputs
+    inputs = promise { read_inputs(input) }
+    input_present = promise { !!inputs.value }
   else
     tokens.shift if source[0] != " "
-    input_present = true
+    input_present = promise { true }
   end
 
-  ast, ast_inds, registers = *parse_main(tokens, input_present)
+  ast, ast_inds, registers = *parse_main(tokens, promise{ $input_checked = true; input_present.value })
 
   ast_cb[ast, ast_inds] if ast_cb
 
@@ -49,7 +49,7 @@ def gen_graph(source, input, pp_sep: nil, ast_cb: nil, ir_cb: nil)
         new_op("input", "[[char]]"){ read_input.value }
       end
     else
-      value, type, rank = parse_input(inputs)
+      value, type, rank = parse_input(inputs.value)
       new_op(type == EmptyType ? "inputEmpty" : "input", type_and_rank_to_str(type, rank)){ value }
     end
   }
