@@ -6,9 +6,9 @@ def run(prog, input, pp)
   File.open("prog.iog", "w"){|f| f << prog }
   File.open("input.txt", "w"){|f| f << input }
   if Array === input
-    `(ruby main.rb prog.iog -hs #{pp ? "-pp" : ""} > test.hs && runhaskell test.hs #{input.map{|i|"'"+i+"'"}*" "}) 2>&1`
+    `(ruby main.rb prog.iog -hs #{pp ? "-p" : ""} > test.hs && runhaskell test.hs #{input.map{|i|"'"+i+"'"}*" "}) 2>&1`
   else
-    `(ruby main.rb prog.iog -hs #{pp ? "-pp" : ""} > test.hs && runhaskell test.hs < input.txt) 2>&1`
+    `(ruby main.rb prog.iog -hs #{pp ? "-p" : ""} > test.hs && runhaskell test.hs < input.txt) 2>&1`
   end
 end
 
@@ -30,6 +30,7 @@ tests.each{|name, prog, input, expected, pp|
   found = run(prog, input, pp)
   found.gsub!("test.hs: \e[31mERROR: \e[0m",'ERROR: ')
   found.gsub!(/\nCallStack.*/m,'')
+  expected.gsub!(/WARNING:.*\n/,'')
 
   if found.chomp != expected.chomp
     STDERR.puts "FAIL: #{name}"
