@@ -1,6 +1,7 @@
 require "./web/examples.rb"
 require "./lazylib.rb"
 require "./run.rb"
+require "stringio"
 
 def output(str)
   $output << str
@@ -10,19 +11,20 @@ pass = true
 
 tests = ExamplesAndTests
 tests.each{|name, prog, input, expected|
-  $ReadStdin = str_to_lazy_list(input).const
-  $ReadStdinLines = read_stdin_lines.const
   begin
     $output = ""
-    run_and_do_io(prog,false,false)
+    input_stream = Array === input ? input : StringIO.new(input)
+    run_and_do_io(prog,input_stream,false,false)
 
     if $output != expected
       STDERR.puts "FAIL: #{name}"
       STDERR.puts prog
       STDERR.puts "expected:"
-      STDERR.puts expected
+      STDERR.print expected
+      STDERR.puts "EOF"
       STDERR.puts "found:"
-      STDERR.puts $output
+      STDERR.print $output
+      STDERR.puts "EOF"
       pass = false
     end
   rescue => e
