@@ -14,9 +14,6 @@ n = 100000
 1.upto(8){|program_size|
   ([all.size**program_size,n].min).times{|i|
     input = ["","\n","ab12","12","1 2","1 2\n3","c","ab\n\n2"].sample
-    $ReadStdin = str_to_lazy_list(input).const
-    $ReadStdinLines = read_stdin_lines.const
-
 
     program = program_size.times.map{ all.sample }*""
     $stdout = StringIO.new("")
@@ -24,7 +21,7 @@ n = 100000
       STDERR.puts "program: " + program
       STDERR.puts "input: " + input
       Timeout::timeout(0.01) {
-        run_and_do_io(program, false, false)
+        run_and_do_io(program, StringIO.new(input), false, false)
       }
     rescue IogiiError,Timeout::Error => e
 #       STDERR.puts e.message
