@@ -4,7 +4,6 @@ require "./run.rb"
 
 special_things = %w'$ ! > , : ; [ { f F m M i I e E nil del superpad implicit input type show set let del  1,2,3 0,0 1,2,,3,4 "asdf" "" 1000'
 
-
 all = ["\n",*' '..'~'] + special_things*3 + [" "]*2
 
 n = 3000
@@ -33,7 +32,7 @@ end
     begin
       STDERR.puts "program: " + program
       Timeout::timeout(0.01) {
-        run_and_do_io(program, input, false, false)
+        run_and_do_io(program, StringIO.new(input), false, false)
       }
     rescue IogiiError => e
       $stdout << e.message
