@@ -33,5 +33,6 @@ view quickref/site
 test online interpreter
 check version number in quickref/#!iogii/tgz/online interpreter/haskell
 ruby web/upload.rb
-create snapshot, e.g. putweb golfscript.com public_html/iogii/0.2 ../site_uploaded/*'
+create snapshot, e.g. putweb golfscript.com public_html/iogii/0.2 ../site_uploaded/*
+'
 end
